pub struct LightChunkSlotArray<T> {
values: Box<[Option<T>]>,
}Expand description
Optional value slots for ScalableLux’s 5x5 chunk cache arrays.
Fields
values: Box<[Option<T>]>Implementations
Sourceimpl<T> LightChunkSlotArray<T>
impl<T> LightChunkSlotArray<T>
Sourcepub fn slot_count(&self) -> usize
pub fn slot_count(&self) -> usize
Returns the number of chunk slots.
Sourcepub fn insert(&mut self, chunk: CachedLightChunk, value: T) -> Option<T>
pub fn insert(&mut self, chunk: CachedLightChunk, value: T) -> Option<T>
Inserts a value at a cached chunk slot.
Sourcepub fn insert_slot(&mut self, chunk_slot: usize, value: T) -> Option<T>
pub fn insert_slot(&mut self, chunk_slot: usize, value: T) -> Option<T>
Inserts a value at a raw chunk slot.
Sourcepub fn get(&self, chunk: CachedLightChunk) -> Option<&T>
pub fn get(&self, chunk: CachedLightChunk) -> Option<&T>
Returns the value at a cached chunk slot.
Sourcepub fn get_mut(&mut self, chunk: CachedLightChunk) -> Option<&mut T>
pub fn get_mut(&mut self, chunk: CachedLightChunk) -> Option<&mut T>
Returns the mutable value at a cached chunk slot.
Sourcepub fn get_mut_slot(&mut self, chunk_slot: usize) -> Option<&mut T>
pub fn get_mut_slot(&mut self, chunk_slot: usize) -> Option<&mut T>
Returns the mutable value at a raw chunk slot.